@@ -1,9 +1,8 @@
 import asyncio
 import functools
 
+
 # every coroutine
-
-
 async def pause(sleep, *args, **kwargs):
     await asyncio.sleep(sleep)
     return [sleep, *args], kwargs
@@ -52,21 +51,19 @@ def renew(task, coro, fargs, *args, **kwargs):
             stop = result_kwargs.get('stop')
             if not stop:
                 task = loop.create_task(
-                    coromask(coro, result_args, result_kwargs, fargs),
-                    name=task.get_name())
+                    coromask(coro, result_args, result_kwargs, fargs), )
                 task.add_done_callback(
                     functools.partial(renew, task, coro, fargs))
             else:
                 return "STOPPED"
         except asyncio.InvalidStateError as ie:
-            print("Invalid State Error", ie,
-                  "Coro", coro,
-                  "args", args,
+            print("Invalid State Error", ie, "Coro", coro, "args", args,
                   "kargs", kwargs)
             raise ie
         except Exception as e:
             print(
-                f"Resultado  cancelled {task.cancelled()}, {task}, coro {coro}, fargs {fargs}")
+                f"Resultado  cancelled {task.cancelled()}, {task}, coro {coro}, fargs {fargs}"
+            )
             print("Excepcion en renew", e)
             raise e
     else:
@@ -134,10 +131,7 @@ class TaskLoop:
     - time_pause :: cantidad de tiempo en pause por cada iteración de loop
 
     """
-    control_words = {"START",
-                     "PAUSE",
-                     "CONTINUE",
-                     "STOP"}
+    control_words = {"START", "PAUSE", "CONTINUE", "STOP"}
     _name = "taskloop"
 
     def __init__(self, coro, coro_args=[], coro_kwargs={}, *args, **kwargs):
@@ -180,21 +174,11 @@ class TaskLoop:
         self._name = name
 
     def create(self):
-        task = self.loop.create_task(
-            coromask(
-                self.coro,
-                self.coro_args,
-                self.coro_kwargs,
-                self.fargs),
-            name=self.name
-        )
+        task = self.loop.create_task(coromask(self.coro, self.coro_args,
+                                              self.coro_kwargs, self.fargs),
+                                     name=self.name)
         task.add_done_callback(
-            functools.partial(
-                self.renew,
-                task,
-                self.coro,
-                self.fargs)
-        )
+            functools.partial(self.renew, task, self.coro, self.fargs))
         return task
 
     def renew(self, task, coro, fargs, *args, **kwargs):
@@ -217,29 +201,38 @@ class TaskLoop:
                 elif self.control in {"START", "CONTINUE"}:
                     if self.control == 'CONTINUE':
                         coro = self.coro
-                    task = loop.create_task(
-                        coromask(coro, result_args, result_kwargs, fargs),
-                        name=self.name)
+                    task = loop.create_task(coromask(coro, result_args,
+                                                     result_kwargs, fargs),
+                                            name=self.name)
                     task.add_done_callback(
                         functools.partial(self.renew, task, coro, fargs))
                 elif self.control == "PAUSE":
                     pause_args = [self.time_pause]
                     pause_kwargs = {}
-                    task = loop.create_task(
-                        coromask(pause, pause_args, pause_kwargs, fargs),
-                        name=self.name)
+                    task = loop.create_task(coromask(pause, pause_args,
+                                                     pause_kwargs, fargs),
+                                            name=self.name)
                     task.add_done_callback(
                         functools.partial(self.renew, task, pause, fargs))
             except asyncio.InvalidStateError as ie:
-                print("Invalid State Error", ie,
-                      "Coro", coro,
-                      "args", args,
+                print("Invalid State Error", ie, "Coro", coro, "args", args,
                       "kargs", kwargs)
                 raise ie
             except Exception as e:
-                print(
-                    f"Resultado  cancelled {task.cancelled()}, {task}, coro {coro}, fargs {fargs}")
-                print("Excepcion en renew", e)
+                log = result_kwargs.get('log')
+                msg = f"""TaskLoop. TResultado  cancelled {task.cancelled()},
+                    task {task},
+                    coro {coro},
+                    fargs {fargs}"""
+                if task.done():
+                    msg_done = f"TaskLoop, exception, Task done {task.result()}"
+                    print(msg_done)
+                    if log:
+                        log.exception(msg)
+                print(msg)
+                if log:
+                    log.exception(msg)
+                print("TaskLoop. Excepcion en renew", e)
                 raise e
         else:
             try:
